==> ejc-zatopbpm-impl-3.0.0-20230919.024909-21-sources.jar: com/ejianc/zatopbpm/bean/BpmInfoEntity.java <==
package com.ejianc.zatopbpm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 审批信息表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zatopbpm_info")
public class BpmInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_id")
    private Long billId; // 单据id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bpm_id")
    private String bpmId; // 审批id
    @TableField(value="zatop_url")
    private String zatopUrl; // 第三方流程的页面url
    @TableField(value="pcurl")
    private String pcurl; // 单据pc端路由
    @TableField(value="maurl")
    private String maurl; // 单据移动端路由
    @TableField(value="type")
    private String type; // 流程状态--与第三方流程同步
    @TableField(value="userid")
    private String userid; // 用户编码
    @TableField(value="zatopbpm_version")
    private String zatopbpmVersion; // 业务对象对应的版本(第三方系统使用判断校验)

    @TableField(value="org_id")
    private Long orgId; // 提交组织id
    @TableField(value="org_source_id")
    private String orgSourceId; // 单据移动端路由
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBpmId() {
        return bpmId;
    }

    public void setBpmId(String bpmId) {
        this.bpmId = bpmId;
    }
    public String getZatopUrl() {
        return zatopUrl;
    }

    public void setZatopUrl(String zatopUrl) {
        this.zatopUrl = zatopUrl;
    }
    public String getPcurl() {
        return pcurl;
    }

    public void setPcurl(String pcurl) {
        this.pcurl = pcurl;
    }
    public String getMaurl() {
        return maurl;
    }

    public void setMaurl(String maurl) {
        this.maurl = maurl;
    }
    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }
    public String getZatopbpmVersion() {
        return zatopbpmVersion;
    }

    public void setZatopbpmVersion(String zatopbpmVersion) {
        this.zatopbpmVersion = zatopbpmVersion;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
}

==> ejc-zatopbpm-impl-3.0.0-20230928.013518-65-sources.jar: com/ejianc/zatopbpm/bean/BpmInfoEntity.java <==
package com.ejianc.zatopbpm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 审批信息表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zatopbpm_info")
public class BpmInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_id")
    private Long billId; // 单据id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型名称
    @TableField(value="bpm_id")
    private String bpmId; // 审批id
    @TableField(value="zatop_url")
    private String zatopUrl; // 第三方流程的页面url
    @TableField(value="pcurl")
    private String pcurl; // 单据pc端路由
    @TableField(value="maurl")
    private String maurl; // 单据移动端路由
    @TableField(value="type")
    private String type; // 流程状态--与第三方流程同步
    @TableField(value="user_id")
    private Long userId; // 用户id
    @TableField(value="user_code")
    private String userCode; // 用户编码
    @TableField(value="user_name")
    private String userName; // 用户名称
    @TableField(value="zatopbpm_version")
    private String zatopbpmVersion; // 业务对象对应的版本(第三方系统使用判断校验)

    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 提交组织id
    @TableField(value="org_source_id")
    private String orgSourceId; // 单据移动端路由
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBpmId() {
        return bpmId;
    }

    public void setBpmId(String bpmId) {
        this.bpmId = bpmId;
    }
    public String getZatopUrl() {
        return zatopUrl;
    }

    public void setZatopUrl(String zatopUrl) {
        this.zatopUrl = zatopUrl;
    }
    public String getPcurl() {
        return pcurl;
    }

    public void setPcurl(String pcurl) {
        this.pcurl = pcurl;
    }
    public String getMaurl() {
        return maurl;
    }

    public void setMaurl(String maurl) {
        this.maurl = maurl;
    }
    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getZatopbpmVersion() {
        return zatopbpmVersion;
    }

    public void setZatopbpmVersion(String zatopbpmVersion) {
        this.zatopbpmVersion = zatopbpmVersion;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
}
